@@ -5,15 +5,20 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
         v => 1,
         summary => 'Convert first character of string to lowercase',
         target_type => 'str',
+        examples => [
+            {value=>'foo'},
+            {value=>'Foo', filtered_value=>'foo'},
+            {value=>'FOO', filtered_value=>'fOO'},
+        ],
     };
 }
 
@@ -44,7 +49,7 @@ Data::Sah::Filter::js::Str::lcfirst - Convert first character of string to lower
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::js::Str::lcfirst (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::js::Str::lcfirst (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -67,6 +72,12 @@ This document describes version 0.011 of Data::Sah::Filter::js::Str::lcfirst (fr
  my $filter = gen_filter([["Str::lcfirst"]]);
  my $filtered_value = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ "foo" # valid, unchanged
+ "Foo" # valid, becomes "foo"
+ "FOO" # valid, becomes "fOO"
+
 =for Pod::Coverage ^(meta|filter)$
 
 =head1 HOMEPAGE
@@ -98,9 +109,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
