@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
@@ -16,6 +16,11 @@ sub meta {
         might_fail => 1,
         args => {
         },
+        examples => [
+            {value=>1, valid=>1},
+            {value=>-1.1, valid=>0},
+            {value=>1.1, valid=>0},
+        ],
     };
 }
 
@@ -47,7 +52,7 @@ Data::Sah::Filter::perl::Float::check_int - Check that a floating point number i
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Float::check_int (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::perl::Float::check_int (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -71,6 +76,12 @@ This document describes version 0.011 of Data::Sah::Filter::perl::Float::check_i
  # $errmsg will be empty/undef when filtering succeeds
  my ($errmsg, $filtered_value) = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ 1 # valid, unchanged
+ -1.1 # INVALID (Number must be an integer), unchanged
+ 1.1 # INVALID (Number must be an integer), unchanged
+
 =head1 DESCRIPTION
 
 This filter checks that number is an integer, i.e. 2.5 fails but 2 succeeds.
@@ -106,9 +117,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
