@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
@@ -18,6 +18,13 @@ sub meta {
                 schema => 'ufloat*',
             },
         },
+        examples => [
+            {value=>1, filtered_value=>1},
+            {value=>-1.1, filtered_value=>-1},
+            {value=>1.1, filtered_value=>1},
+            {value=>1.1, filter_args=>{nearest=>0.5}, filtered_value=>1},
+            {value=>1.3, filter_args=>{nearest=>0.5}, filtered_value=>1.5},
+        ],
     };
 }
 
@@ -53,7 +60,7 @@ Data::Sah::Filter::perl::Float::round - Round number to the nearest integer (or
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Float::round (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::perl::Float::round (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -76,6 +83,14 @@ This document describes version 0.011 of Data::Sah::Filter::perl::Float::round (
  my $filter = gen_filter([["Float::round"]]);
  my $filtered_value = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ 1 # valid, unchanged
+ -1.1 # valid, becomes -1
+ 1.1 # valid, becomes 1
+ 1.1 # filtered with args {nearest=>0.5}, valid, becomes 1
+ 1.3 # filtered with args {nearest=>0.5}, valid, becomes 1.5
+
 =for Pod::Coverage ^(meta|filter)$
 
 =head1 HOMEPAGE
@@ -108,9 +123,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
