@@ -5,14 +5,19 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
         v => 1,
         summary => 'Convert string to lowercase',
+        examples => [
+            {value=>'foo'},
+            {value=>'Foo', filtered_value=>'foo'},
+            {value=>'FOO', filtered_value=>'foo'},
+        ],
     };
 }
 
@@ -45,7 +50,7 @@ Data::Sah::Filter::perl::Str::lc - Convert string to lowercase
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Str::lc (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::perl::Str::lc (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -68,6 +73,12 @@ This document describes version 0.011 of Data::Sah::Filter::perl::Str::lc (from
  my $filter = gen_filter([["Str::lc"]]);
  my $filtered_value = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ "foo" # valid, unchanged
+ "Foo" # valid, becomes "foo"
+ "FOO" # valid, becomes "foo"
+
 =for Pod::Coverage ^(meta|filter)$
 
 =head1 HOMEPAGE
@@ -102,9 +113,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
