@@ -7,9 +7,9 @@ use warnings;
 use Data::Dmp;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
@@ -21,6 +21,10 @@ sub meta {
                 req => 1,
             },
         },
+        examples => [
+            {value=>"foo", filter_args=>{map=>{foo=>"bar", baz=>"qux"}}, filtered_value=>"bar"},
+            {value=>"bar", filter_args=>{map=>{foo=>"bar", baz=>"qux"}}},
+        ],
     };
 }
 
@@ -58,7 +62,7 @@ Data::Sah::Filter::perl::Str::replace_map - Replace (map) some values with (to)
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Str::replace_map (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::perl::Str::replace_map (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -81,6 +85,11 @@ This document describes version 0.011 of Data::Sah::Filter::perl::Str::replace_m
  my $filter = gen_filter([["Str::replace_map"]]);
  my $filtered_value = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ "foo" # filtered with args {map=>{baz=>"qux",foo=>"bar"}}, valid, becomes "bar"
+ "bar" # filtered with args {map=>{baz=>"qux",foo=>"bar"}}, valid, unchanged
+
 =head1 DESCRIPTION
 
 This filter rule can be used to replace some (e.g. old) values to other (e.g.
@@ -123,9 +132,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
