@@ -5,14 +5,20 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub meta {
     +{
         v => 1,
         summary => 'Convert first character of string to uppercase',
+        examples => [
+            {value=>'foo', filtered_value=>'Foo'},
+            {value=>'Foo'},
+            {value=>'fOO', filtered_value=>'FOO'},
+            {value=>'FOO'},
+        ],
     };
 }
 
@@ -45,7 +51,7 @@ Data::Sah::Filter::perl::Str::ucfirst - Convert first character of string to upp
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Str::ucfirst (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::Filter::perl::Str::ucfirst (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -68,6 +74,13 @@ This document describes version 0.011 of Data::Sah::Filter::perl::Str::ucfirst (
  my $filter = gen_filter([["Str::ucfirst"]]);
  my $filtered_value = $filter->($some_data);
 
+=head2 Sample data and filtering results
+
+ "foo" # valid, becomes "Foo"
+ "Foo" # valid, unchanged
+ "fOO" # valid, becomes "FOO"
+ "FOO" # valid, unchanged
+
 =for Pod::Coverage ^(meta|filter)$
 
 =head1 HOMEPAGE
@@ -99,9 +112,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
