@@ -6,15 +6,14 @@ use warnings;
 use Log::ger;
 
 use Data::Sah::FilterCommon;
+use Exporter qw(import);
 use IPC::System::Options;
 use Nodejs::Util qw(get_nodejs_path);
 
-use Exporter qw(import);
-
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our @EXPORT_OK = qw(gen_filter);
 
@@ -32,15 +31,15 @@ This is mostly for testing. Normally the filter rules will be used from
 
 _
     args => {
-        filter_names => {
-            schema => ['array*', of=>'str*'],
-        },
+        %Data::Sah::FilterCommon::gen_filter_args,
     },
     result_naked => 1,
 };
 sub gen_filter {
     my %args = @_;
 
+    my $rt = $args{return_type} // 'val';
+
     my $rules = Data::Sah::FilterCommon::get_filter_rules(
         %args,
         compiler=>'js',
@@ -55,7 +54,24 @@ sub gen_filter {
             "    if (data === undefined || data === null) {\n",
             "        return null;\n",
             "    }\n",
-            (map { "    data = $_->{expr_filter};\n" } @$rules),
+        );
+        for my $rule (@$rules) {
+            if ($rule->{meta}{might_fail}) {
+                if ($rt eq 'val') {
+                    $code .= "    tmp = $rule->{expr_filter}; if (tmp[0]) { return null; } data = tmp[1]\n";
+                } else {
+                    $code .= "    tmp = $rule->{expr_filter}; if (tmp[0]) { return tmp; }  data = tmp[1]\n";
+                }
+            } else {
+                if ($rt eq 'val') {
+                    $code .= "    data = $rule->{expr_filter}\n";
+                } else {
+                    $code .= "    data = [false, $rule->{expr_filter}]\n";
+                }
+            }
+        }
+        $code .= join(
+            '',
             "    return data;\n",
             "}",
         );
@@ -110,7 +126,7 @@ Data::Sah::FilterJS - Generate filter code
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::FilterJS (from Perl distribution Data-Sah-Filter), released on 2022-07-16.
+This document describes version 0.014 of Data::Sah::FilterJS (from Perl distribution Data-Sah-Filter), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -154,7 +170,13 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<filter_names> => I<array[str]>
+=item * B<filter_names>* => I<array[str]>
+
+(No description)
+
+=item * B<return_type> => I<str> (default: "val")
+
+(No description)
 
 
 =back
@@ -199,9 +221,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
